netapp_ontap.models.fc_zone_members API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fc_zone_members`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FcZoneMembersSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FcZoneMembers object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `name: str GET`

    The identifying property value of the zone member. The format of this value depends on the member type:

    - `port_id`: A zero-filled 6-digit hexadecimal value with a 0x prefer. Example: 0x0000A0.
    - `port_name`: A world-wide name. Example: 10:00:12:34:56:78:9a:bc.
    - `domain_id_port`: A domain ID and a port ID as decimal integers separated by a slash. Example: 1/2.
    - `node_name`: A world-wide name. Example: 10:00:11:22:33:44:55:66.
    - `fabric_port_name`: A world-wide name. Example: 10:00:ab:cd:ef:12:34:56.

    #####

    The following types might not report a name:

    - `interface`
    - `domain_interface`
    - `ip_address`
    - `symbolic_node_name`
    - `device_alias`

    Example: 10:00:12:34:56:78:9a:bc

  `type: str GET`

    The type of Fibre Channel zone member. This value should be used to interpret the contents of the `name` property.

    Valid choices:

    - port_id
    - port_name
    - domain_id_port
    - node_name
    - fabric_port_name
    - interface
    - domain_interface
    - ip_address
    - symbolic_node_name
    - device_alias